..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Contributors
============

- Alexander Ioannidis
- Dinos Kousidis
- Harris Tzovanakis
- Lars Holm Nielsen
- Leonardo Rossi
- Nikos Filippakis
- Rémi Ducceschi
- Tibor Simko
